@@ -412,7 +412,7 @@ def run():
 class Daemon(object):
     def __init__(self):
         # Set global to ourself
-        global _INSTANCE
+        global _INSTANCE  # pylint: disable=global-statement
         _INSTANCE = self
 
         # When this is not None, daemon is running
@@ -533,8 +533,7 @@ class Daemon(object):
 
     @classmethod
     def meta(cls, model, func, msglog):
-        # pylint: disable=W0123
-        model_class = eval("mini_buildd.models.{m}.Admin".format(m=model))
+        model_class = eval("mini_buildd.models.{m}.Admin".format(m=model))  # pylint: disable=eval-used
         getattr(model_class, "mbd_meta_{f}".format(f=func))(msglog)
 
     @classmethod
@@ -746,9 +745,3 @@ _INSTANCE = None
 def get():
     assert _INSTANCE
     return _INSTANCE
-
-
-if __name__ == "__main__":
-    mini_buildd.misc.setup_console_logging()
-    import doctest
-    doctest.testmod()
